@@ -76,7 +76,7 @@ class Repl:
 
         self.console.write("pixpy REPL\n")
         self.console.write('> ')
-        self.console.get_line()
+        self.console.read_line()
 
     def run_repl(self):
         while pix.run_loop():
@@ -86,7 +86,7 @@ class Repl:
                 if self.textedit.want_to_quit:
                     self.editing = False
                     self.textedit.want_to_quit = False
-                    self.console.get_line()
+                    self.console.read_line()
             for e in pix.all_events():
                 if type(e) == pix.event.Resize:
                     self.canvas = Canvas(self.screen.size)
@@ -123,7 +123,7 @@ class Repl:
                     except Exception as e:
                         self.console.write(f"## {e}\n> ")
                     if not self.editing:
-                        self.console.get_line()
+                        self.console.read_line()
 
             con = self.console
             if self.editing:
