@@ -14,16 +14,30 @@ namespace pix {
 
 class Context
 {
+    // The GL target frame buffer
     GLuint target = 0;
-    Vec2f offset{0, 0};
 
+    // The XY offset of our view into the framebuffer
+    Vec2f offset{0, 0};
+    // The size of our view into the framebuffer
+    Vec2f view_size{0, 0};
 public:
+    // Actual size of framebuffer
+    Vec2f target_size;
+
+    // Clip (scissor) area
     Vec2i clip_start{0,0};
     Vec2i clip_size{0,0};
 
-    Vec2f target_size;
+    std::shared_ptr<gl_wrap::Texture> texture;
+
+    // Viewport scale (for when window size != framebuffer size)
     float vpscale = 1.0F;
 
+    mutable bool dirty = false;
+
+    std::unique_ptr<uint32_t[]> pixels; // NOLINT
+
     float line_width = 1;
     float point_size = 2;
     gl_wrap::Color fg;
@@ -69,12 +83,22 @@ public:
     }
 
     Context(float w, float h, GLuint fb = 0);
-    Context(Vec2f const& offset, Vec2f const& size, GLuint fb = 0);
+    Context(Vec2f _offset, Vec2f _view_size, Vec2f _target_size, GLuint fb = 0);
 
-    Vec2f const& screen_size() { return target_size; }
+    Vec2f screen_size() const { return target_size; }
 
     void set_target() const;
 
+    void resize(Vec2f size, float scale)
+    {
+        target_size = size;
+        vpscale = scale;
+    }
+    void set_pixel(int x, int y, uint32_t col);
+
+    void flush_pixels();
+
+
     void set_color(gl_wrap::Color const& col);
 
     void circle(Vec2f const& v, float r);
