@@ -27,7 +27,7 @@ struct Texture
         glGenTextures(1, &tex_id);
         glBindTexture(GL_TEXTURE_2D, tex_id);
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MAG_FILTER, GL_NEAREST);
-        glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR);
+        glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_S, GL_CLAMP_TO_EDGE);
         glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_WRAP_T, GL_CLAMP_TO_EDGE);
     }
@@ -127,6 +127,7 @@ struct Texture
 
     ~Texture()
     {
+
         if (tex_id != 0) { glDeleteTextures(1, &tex_id); }
         if (fb_id != 0) { glDeleteFramebuffers(1, &fb_id); }
     };
@@ -147,30 +148,30 @@ struct Texture
 
     void set_target()
     {
-        if (fb_id == 0) {
-            // glActiveTexture(GL_TEXTURE0);
-            glBindTexture(GL_TEXTURE_2D, tex_id);
-            glGenFramebuffers(1, &fb_id);
-            glBindFramebuffer(GL_FRAMEBUFFER, fb_id);
-            glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0,
-                                   GL_TEXTURE_2D, tex_id, 0);
-        } else {
+        if(!alloc_framebuffer()) {
             glBindFramebuffer(GL_FRAMEBUFFER, fb_id);
         }
         setViewport({width, height});
     }
 
     GLuint get_target()
+    {
+        alloc_framebuffer();
+        return fb_id;
+    }
+
+    bool alloc_framebuffer()
     {
         if (fb_id == 0) {
-            // glActiveTexture(GL_TEXTURE0);
             glBindTexture(GL_TEXTURE_2D, tex_id);
             glGenFramebuffers(1, &fb_id);
             glBindFramebuffer(GL_FRAMEBUFFER, fb_id);
             glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0,
                                    GL_TEXTURE_2D, tex_id, 0);
+            gl_check("glFrameBufferTexture2d");
+            return true;
         }
-        return fb_id;
+        return false;
     }
 
     std::vector<std::byte> read_pixels(int x = 0, int y = 0, int w = -1,
@@ -179,17 +180,7 @@ struct Texture
         if (w < 0) { w = width; }
         if (h < 0) { h = height; }
 
-        GLuint fb = 0;
-        if (fb_id == 0) {
-            glGenFramebuffers(1, &fb);
-            glBindFramebuffer(GL_FRAMEBUFFER, fb);
-            glFramebufferTexture2D(GL_FRAMEBUFFER, GL_COLOR_ATTACHMENT0,
-                                   GL_TEXTURE_2D, tex_id, 0);
-            gl_check("glFrameBufferTexture2d");
-            setViewport({width, height});
-        } else {
-            set_target();
-        }
+        set_target();
         std::vector<std::byte> data(width * height * 4);
         auto type = GL_UNSIGNED_BYTE;
         glReadPixels(x, height - y - h, w, h, format, type, data.data());
@@ -200,7 +191,7 @@ struct Texture
 
     template <typename T>
     void update(T const* ptr, GLint source_format = -1,
-                GLenum type = GL_UNSIGNED_BYTE)
+                GLenum type = GL_UNSIGNED_BYTE) const
     {
         if (source_format < 0) {
             constexpr static std::array translate{0, GL_ALPHA, 0, GL_RGB,
@@ -214,7 +205,7 @@ struct Texture
 
     template <typename T>
     void update(int x, int y, int w, int h, T const* ptr,
-                GLint source_format = -1, GLenum type = GL_UNSIGNED_BYTE)
+                GLint source_format = -1, GLenum type = GL_UNSIGNED_BYTE) const
     {
         if (source_format < 0) {
             constexpr static std::array translate{0, GL_ALPHA, 0, GL_RGB,
@@ -227,7 +218,7 @@ struct Texture
 
     std::pair<float, float> size() const
     {
-        return {(float)width, (float)height};
+        return {static_cast<float>(width), (float)height};
     }
 };
 
@@ -243,7 +234,7 @@ public:
     // Constructors
     TexRef() = default;
     TexRef(int w, int h) : tex{std::make_shared<Texture>(w, h)} {}
-    TexRef(std::pair<int, int> size)
+    explicit TexRef(std::pair<int, int> size)
         : tex{std::make_shared<Texture>(size.first, size.second)}
     {
     }
@@ -267,7 +258,7 @@ public:
     void copy_from(gl_wrap::TexRef const& src) const
     {
         using gl_wrap::ProgramCache;
-        GLint fb;
+        GLint fb = 0;
         glGetIntegerv(GL_FRAMEBUFFER_BINDING, &fb);
         auto old = gl_wrap::getViewport();
         set_target();
@@ -313,10 +304,13 @@ public:
 
     void copy_to(TexRef const& target) const { target.copy_from(*this); }
 
-    float ytou(double yy) { return static_cast<float>(1.0 - yy / tex->height); }
-    float xtov(double xx) { return static_cast<float>(xx / tex->width); }
+    float ytou(double yy) const
+    {
+        return static_cast<float>(1.0 - yy / tex->height);
+    }
+    float xtov(double xx) const { return static_cast<float>(xx / tex->width); }
 
-    TexRef crop(double x, double y, double w, double h)
+    TexRef crop(double x, double y, double w, double h) const
     {
         float u0 = xtov(this->x() + x);
         float v0 = ytou(this->y() + y);
