@@ -59,8 +59,8 @@ PixConsole::PixConsole(int w, int h, FreetypeFont& ftfont)
     init();
 }
 */
-PixConsole::PixConsole(int w, int h, std::shared_ptr<TileSet> const& _font)
-    : font{_font},  cols{w}, rows{h}
+PixConsole::PixConsole(int _cols, int _rows, std::shared_ptr<TileSet> const& _tile_set)
+    : tile_set{_tile_set},  cols{_cols}, rows{_rows}
 {
     init();
 }
@@ -84,7 +84,7 @@ void PixConsole::init()
     program.setUniform("col_tex", 2);
 
     program.setUniform("console_size", std::pair<float, float>(cols, rows));
-    program.setUniform("uv_scale", font->get_uvscale());
+    program.setUniform("uv_scale", tile_set->get_uvscale());
 
     uv_texture.update(uvdata.data());
     col_texture.update(coldata.data());
@@ -92,7 +92,7 @@ void PixConsole::init()
 
 template <typename T> std::pair<T, T> PixConsole::get_char_size() const
 {
-    return {static_cast<T>(font->char_width), static_cast<T>(font->char_height)};
+    return {static_cast<T>(tile_set->char_width), static_cast<T>(tile_set->char_height)};
 }
 
 template std::pair<float, float> PixConsole::get_char_size() const;
@@ -124,7 +124,7 @@ std::pair<int, int> PixConsole::text(int x, int y, std::u32string const& text32,
             continue;
         }
 
-        uvdata[x + cols * y] = font->get_offset(c) | w0;
+        uvdata[x + cols * y] = tile_set->get_offset(c) | w0;
         coldata[x + cols * y] = w1;
         x++;
         if (x >= cols) {
@@ -140,21 +140,21 @@ void PixConsole::put_char(int x, int y, char32_t c)
 {
     uv_dirty = col_dirty = true;
     auto& u = uvdata[x + cols * y];
-    u = (u & 0xffff0000) | font->get_offset(c);
+    u = (u & 0xffff0000) | tile_set->get_offset(c);
 }
 
 void PixConsole::put(int x, int y, uint32_t fg, uint32_t bg, char32_t c)
 {
     uv_dirty = col_dirty = true;
     auto [w0, w1] = make_col(fg, bg);
-    uvdata[x + cols * y] = font->get_offset(c) | w0;
+    uvdata[x + cols * y] = tile_set->get_offset(c) | w0;
     coldata[x + cols * y] = w1;
 }
 
 uint32_t PixConsole::get_char(int x, int y)
 {
     uint32_t uv = uvdata[x + cols * y] & 0xffff;
-    return font->get_char_from_uv(uv);
+    return tile_set->get_char_from_uv(uv);
 }
 
 std::vector<uint32_t> PixConsole::get_tiles()
@@ -164,7 +164,7 @@ std::vector<uint32_t> PixConsole::get_tiles()
         uint32_t uv = uvdata[i] & 0xffff;
         auto fg = ((coldata[i] & 0xff000000)>>16) | (uvdata[i] & 0xffff0000);
         auto bg = coldata[i] & 0xffffff;
-        result[i*3] = font->get_char_from_uv(uv);
+        result[i*3] = tile_set->get_char_from_uv(uv);
         result[i*3+1] = fg;
         result[i*3+2] = bg;
     }
@@ -175,7 +175,7 @@ void PixConsole::set_tiles(std::vector<uint32_t> const& data)
 {
     for(int i=0; i<cols*rows; i++) {
         auto [w0,w1] = make_col(data[i*3+1], data[i*3+2]);
-        uvdata[i] = font->get_offset(data[i*3]) | w0;
+        uvdata[i] = tile_set->get_offset(data[i*3]) | w0;
         coldata[i] = w1;
     }
     uv_dirty = true;
@@ -194,7 +194,7 @@ void PixConsole::fill(uint32_t fg, uint32_t bg)
 {
     uv_dirty = col_dirty = true;
     auto [w0, w1] = make_col(fg, bg);
-    w0 |= font->char_uvs[' '];
+    w0 |= tile_set->char_uvs[' '];
     for (size_t i = 0; i < uvdata.size(); i++) {
         uvdata[i] = w0;
         coldata[i] = w1;
@@ -217,7 +217,7 @@ void PixConsole::clear_area(int32_t x, int32_t y, int32_t w, int32_t h,
     if (w == -1) { w = cols; }
     if (h == -1) { h = rows; }
     auto [w0, w1] = make_col(fg, bg);
-    w0 |= font->char_uvs[' '];
+    w0 |= tile_set->char_uvs[' '];
     for (int32_t yy = 0; yy < h; yy++) {
         for (int32_t xx = 0; xx < w; xx++) {
             auto offs = (xx + x) + (yy + y) * cols;
@@ -255,7 +255,7 @@ void PixConsole::render(float x0, float y0, float x1, float y1)
     glDisable(GL_BLEND);
     col_texture.bind(2);
     uv_texture.bind(1);
-    font->tile_texture->bind(0);
+    tile_set->tile_texture->bind(0);
 
     program.use();
 
@@ -279,5 +279,5 @@ void PixConsole::render(float x0, float y0, float x1, float y1)
 
 std::pair<int, int> PixConsole::get_pixel_size() const
 {
-    return {cols * font->char_width, rows * font->char_height};
+    return {cols * tile_set->char_width, rows * tile_set->char_height};
 }
