@@ -19,7 +19,7 @@ class PixConsole
 
     gl_wrap::Program program;
 
-    std::shared_ptr<TileSet> font;
+    std::shared_ptr<TileSet> tile_set;
 
     int cols;
     int rows;
@@ -45,7 +45,7 @@ class PixConsole
     void init();
 
 public:
-    PixConsole(int cols, int rows, std::shared_ptr<TileSet> const& font);
+    PixConsole(int _cols, int _rows, std::shared_ptr<TileSet> const& _tile_set);
 
     std::vector<uint32_t> get_tiles();
     void set_tiles(std::vector<uint32_t> const& data);
@@ -56,12 +56,12 @@ public:
 
     std::shared_ptr<gl_wrap::Texture> get_font_texture() const
     {
-        return font->tile_texture;
+        return tile_set->tile_texture;
     }
 
     gl_wrap::TexRef get_texture_for_char(char32_t c)
     {
-        return font->get_texture_for_char(c);
+        return tile_set->get_texture_for_char(c);
     }
 
     std::pair<int, int> text(int x, int y, std::string const& t,
