@@ -83,8 +83,7 @@ std::shared_ptr<Screen> open_display(int width, int height, bool full_screen)
     m.sys->add_listener([](AnyEvent const& e) {
         if (std::holds_alternative<ResizeEvent>(e)) {
             auto [w, h] = m.screen->get_size();
-            m.context->target_size = Vec2f(w, h);
-            m.context->vpscale = m.screen->get_scale();
+            m.context->resize(Vec2f(w,h), m.screen->get_scale());
         }
         return System::Propagate::Pass;
     });
