@@ -19,9 +19,21 @@ inline auto add_screen_class(py::module_ const& mod)
     screen.def_property_readonly("frame_counter", [](Screen const&) {
         return Machine::get_instance().frame_counter;
     });
-    screen.def_property_readonly("context", [](Screen const&) {
-        return Machine::get_instance().context;
-    });
+    screen.def_property_readonly(
+        "seconds",
+        [](Screen const& screen) { return screen.get_time().seconds; },
+        "Total seconds elapsed.");
+    screen.def_property_readonly(
+        "delta", [](Screen const& screen) { return screen.get_time().delta; },
+        "Time in seconds for last frame.");
+    screen.def_property(
+        "fps", [](Screen const& screen) { return screen.get_time().fps; },
+        [](Screen& screen, int fps) { screen.set_fps(fps); });
+    screen.def_property_readonly(
+        "context",
+        [](Screen const&) { return Machine::get_instance().context; },
+        "Current FPS. Set to 0 to disable fixed FPS. Then use `seconds` or "
+        "`delta` to sync your movement.");
     screen.def_property_readonly(
         "size", [](Screen const& screen) { return Vec2i{screen.get_size()}; });
     screen.def_property_readonly(
