@@ -102,8 +102,18 @@ public:
         int display_height = 1200;
     };
 
+    struct Time
+    {
+        double seconds{};
+        int frame_counter{};
+        double delta{};
+        int fps{};
+    };
+
     virtual ~Screen() = default;
     virtual void swap() {}
+    virtual void set_fps(int fps) {}
+    virtual Time get_time() const { return {}; }
     virtual void set_target(){};
     virtual float get_scale() { return 1.0F; }
     virtual std::pair<int, int> get_size() const { return {-1, -1}; }
